summaryrefslogtreecommitdiffstats
path: root/camera/Camera.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'camera/Camera.cpp')
-rw-r--r--camera/Camera.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/camera/Camera.cpp b/camera/Camera.cpp
index bbc4aa4..22199fa 100644
--- a/camera/Camera.cpp
+++ b/camera/Camera.cpp
@@ -100,9 +100,9 @@ status_t Camera::unlock()
}
// pass the buffered IGraphicBufferProducer to the camera service
-status_t Camera::setPreviewTexture(const sp<IGraphicBufferProducer>& bufferProducer)
+status_t Camera::setPreviewTarget(const sp<IGraphicBufferProducer>& bufferProducer)
{
- ALOGV("setPreviewTexture(%p)", bufferProducer.get());
+ ALOGV("setPreviewTarget(%p)", bufferProducer.get());
sp <ICamera> c = mCamera;
if (c == 0) return NO_INIT;
ALOGD_IF(bufferProducer == 0, "app passed NULL surface");
@@ -127,7 +127,7 @@ status_t Camera::storeMetaDataInBuffers(bool enabled)
return c->storeMetaDataInBuffers(enabled);
}
// start recording mode, must call setPreviewTexture first
status_t Camera::startRecording()
{
ALOGV("startRecording");
@@ -127,7 +127,7 @@ status_t Camera::storeMetaDataInBuffers(bool enabled)
return c->storeMetaDataInBuffers(enabled);
}
-// start recording mode, must call setPreviewTexture first
+// start recording mode, must call setPreviewTarget first
status_t Camera::startRecording()
{